@@ -2,6 +2,7 @@
 
 import logging
 import os
+import platform
 import re
 import socket
 import ssl
@@ -19,7 +20,7 @@ import signal
 import pkg_resources
 from . import OAuth2Receiver, SoundServer, StatTracker
 
-sock_context = ssl.create_default_context()
+ssl_context = ssl.create_default_context()
 sleep_event = threading.Event()
 
 # TODO: this is gonna take ahwile to integrate
@@ -234,7 +235,12 @@ def chat_listener_factory(entry_name: str,
                 elif random_mode == 2 or (random_mode == 1 and message == 'random'):
                     request = SoundServer.SoundRequest(50 if priority_playback else 100, timestamp, random.choice(target_file_list), not chaos)
                 else:
-                    request = SoundServer.SoundRequest(50 if priority_playback else 100, timestamp, target / (message + '.mp3'), not chaos)
+                    fname = message + '.mp3'
+                    selected_file = target / fname
+                    if selected_file.exists():
+                        request = SoundServer.SoundRequest(50 if priority_playback else 100, timestamp, selected_file, not chaos)
+                    else:
+                        logging.error(f'{message + ".mp3"} does not exist')
         if request is not None:
             sound_server.enqueue(request)
             if stat_track:
@@ -358,7 +364,7 @@ def chat_listener(config, server_validation, chat_functions):
             #  MacOS, baby. this just keeps working if you turn the network off and on
             with socket.create_connection((creds['host'], creds['port'])) as sock:
                 sock.setblocking(True)  # The docs DON'T say it DOESN'T work on windows
-                with sock_context.wrap_socket(sock, server_hostname=creds['host']) as ssock:
+                with ssl_context.wrap_socket(sock, server_hostname=creds['host']) as ssock:
                     ssock.send('PASS {}\r\nNICK {}\r\n'.format(creds['oauth'], creds['user']).encode('utf-8'))
                     # ":tmi.twitch.tv NOTICE * :Login authentication failed" on bad oauth. idk about expired
                     # We should expect a "GLHF!" otherwise in the first response
@@ -435,23 +441,24 @@ def chat_listener(config, server_validation, chat_functions):
                                     # congrats, we made it 5 minutes without dying!
                                     retry_count = 0
                                 elif len(components) == 5 and components[2] == 'PRIVMSG':
-                                    try:
-                                        tags = {k: v for k, v in [x.split('=') for x in components[0][1:].split(';')]}
-                                        badges = {k: v for k, v in [x.split('/') for x in tags['badges'].split(',')]}
-                                        timestamp = int(tags['tmi-sent-ts'])
-                                        sender = components[1][1:].split('!', maxsplit=1)[0].lower()
-                                        # display-name can be empty
-                                        sender_display = sender if not tags.get('display-name') else tags['display-name']
-                                        message = components[4][1:]
-                                        logging.info(f'{sender}: {message}')
-                                        # badges: dict, tags: dict, timestamp: int, sender: str, sender_display: str, message: str, **kwargs
-                                        for func in chat_functions:
+                                    tags = {k: v for k, v in [x.split('=') for x in components[0][1:].split(';')]}
+                                    badges = {} if not tags.get('badges') else \
+                                        {k: v for k, v in [x.split('/') for x in tags['badges'].split(',')]}
+                                    timestamp = int(tags['tmi-sent-ts'])
+                                    sender = components[1][1:].split('!', maxsplit=1)[0].lower()
+                                    # display-name can be empty
+                                    sender_display = sender if not tags.get('display-name') else tags['display-name']
+                                    message = components[4][1:]
+                                    logging.info(f'{sender}: {message}')
+                                    # badges: dict, tags: dict, timestamp: int, sender: str, sender_display: str, message: str, **kwargs
+                                    for func in chat_functions:
+                                        try:
                                             if func(badges, tags, timestamp, sender, sender_display, message):
                                                 break
-                                    except Exception as err:
-                                        # FIXME? this isn't a reconnect-level issue, but it's still a problem.
-                                        logging.error(f'Error in message scanner loop: {err}')
-                                        logging.error(traceback.format_exc())
+                                        except Exception as err:
+                                            # FIXME? this isn't a reconnect-level issue, but it's still a problem.
+                                            logging.error(f'Error in message scanner loop: {err}')
+                                            logging.error(traceback.format_exc())
                                 else:
                                     logging.error(f'Mystery message from twitch, probably fine: {msg}')
         except Exception as err:
@@ -470,6 +477,7 @@ def launch_system(config_file: Path, quiet: bool = False):
     """
     Do all the things
     :param config_file: Path to config file
+    :param quiet: silence startup boop
     """
     try:
         config = toml.loads(config_file.read_text())
@@ -531,9 +539,14 @@ def launch_system(config_file: Path, quiet: bool = False):
 
     # TODO: Figure out shutdowns in the various bad spots
     #  (soundserver needing a fake(?) sound, chat listener, (eventually) points listnener)
-    # I think this sleep is preventing interrupts on windows >:C
-    #  Are interrups MainThread only??
-    shutdown_event.wait()
+    # LMFAO FREAKING WINDOWS threading.Event.wait can't be interrupted https://bugs.python.org/issue35935
+    # But since they've been pouring effort into time.sleep to make it not garbage, that might work.
+    if platform.system() == 'Windows':
+        import time
+        while not shutdown_event.is_set():
+            time.sleep(5)
+    else:
+        shutdown_event.wait()
 
     if not quiet:
         soundserver.enqueue(SoundServer.SoundRequest(
